@@ -2,6 +2,7 @@ from django import forms
 from django.contrib.auth.models import User
 from django.contrib.contenttypes.models import ContentType
 from django.contrib.auth.models import Permission
+from django.forms.util import ErrorList
 
 from tendenci.apps.user_groups.models import Group, GroupMembership
 from tendenci.apps.user_groups.utils import member_choices
@@ -9,6 +10,46 @@ from tendenci.core.perms.forms import TendenciBaseForm
 from tendenci.apps.entities.models import Entity
 
 
+SEARCH_CATEGORIES = (
+    ('', '-- SELECT ONE --' ),
+    ('creator__id', 'Creator Userid #'),
+    ('creator__username', 'Creator Username'),
+
+    ('guid', 'User Group GUID'),
+    ('id', 'User Group ID #'),
+    ('label__icontains', 'User Group Label'),
+    ('name__icontains', 'User Group Name'),
+
+    ('owner__id', 'Owner Userid #'),
+    ('owner__username', 'Owner Username'),
+    
+)
+
+
+class GroupSearchForm(forms.Form):
+    search_category = forms.ChoiceField(choices=SEARCH_CATEGORIES, required=False)
+    q = forms.CharField(required=False)
+
+    def clean(self):
+        cleaned_data = self.cleaned_data
+        q = self.cleaned_data.get('q', None)
+        cat = self.cleaned_data.get('search_category', None)
+
+        if q is None or q == "":
+            return cleaned_data
+
+        if cat is None or cat == "" :
+            self._errors['search_category'] =  ErrorList(['Select a category'])
+
+        if cat in ('id', 'owner__id', 'creator__id') :
+            try:
+                x = int(q)
+            except ValueError:
+                self._errors['q'] = ErrorList(['Must be an integer'])
+
+        return cleaned_data
+
+
 class GroupAdminForm(TendenciBaseForm):
     email_recipient = forms.CharField(label="Recipient Email",
                                       required=False, max_length=100,
